from .base import env


DEFAULT_BASE_URL = env.str("LOG_SENTINEL_BASE_URL", default="http://localhost:8000")
DEFAULT_API_KEY = env.str("LOG_SENTINEL_API_KEY")
DEFAULT_BATCH_SIZE = env.int("LOG_SENTINEL_BATCH_SIZE", default=25)
DEFAULT_BATCH_INTERVAL = env.float("LOG_SENTINEL_BATCH_INTERVAL", default=3.0)
DEFAULT_RETRY_ATTEMPTS = env.int("LOG_SENTINEL_RETRY_ATTEMPTS", default=10)
DEFAULT_MIN_REMOTE_LEVEL = env.str("LOG_SENTINEL_MIN_LEVEL", default="WARN")

